atomate.lammps.workflows package — atomate 0.3 documentation

# atomate.lammps.workflows package

## Submodules

## atomate.lammps.workflows.core module

`atomate.lammps.workflows.core.` `get_wf`(job_name, lammps_dict_input, input_filename=u'lammps.inp', lammps_bin=u'lammps', db_file=None, dry_run=False)

  Returns workflow that writes lammps input/data files, runs lammps and inserts to DB.

  Args:

    job_name: job name lammps_dict_input (DictLammpsInput): lammps input input_filename (string): input file name lammps_bin (string): path to the lammps binary db_file (string): path to the db file dry_run (bool): for test purposes, decides whether or not to run the lammps binary

    > with the input file.

  Returns:
    Workflow

## atomate.lammps.workflows.presets module

`atomate.lammps.workflows.presets.` `nvt_wf`(lammps_data, input_filename=u'nvt.inp', data_filename=u'in.data', user_lammps_settings={}, is_forcefield=False, lammps_bin=u'lammps', db_file=None, dry_run=False)
  Returns NVT workflow:
    Firework: [write lammps input task, run direct task]
  Args:
    lammps_data (string/LammpsData/LammpsForceFieldData): path to the data file
      or an appropriate object.

    input_filename (string): input file name data_filename (string): data file name user_lammps_settings (dict): used to override the default input file

    > paramter settings

    is_forcefield (bool): whether or not the data file has forcefiled info. lammps_bin (string): path to the lammps binary db_file (string): path to the db file dry_run (bool): for test purposes, decides whether or not to run the lammps binary

    > with the input file.

`atomate.lammps.workflows.presets.` `wf_from_input_template`(input_template_file, lammps_data, data_filename, user_settings, is_forcefield=False, input_filename=u'lammps.inp', lammps_bin=u'lammps', db_file=None, dry_run=False)

  Returns workflow where the input file parameters are set from the give json template file.

  Args:

    input_template_file: json template input file lammps_data (string/LammpsData/LammpsForceFieldData): path to the data file or

    > an appropriate object

    data_filename (string): name of the the lammps data file user_settings (dict): User lammps settings is_forcefield (bool): whether the data file has forcefield and topology info in it.

    > This is required only if lammps_data is a path to the data file instead of a data object

    input_filename (string): input file name lammps_bin (string): path to the lammps binary db_file (string): path to the db file dry_run (bool): for test purposes, decides whether or not to run the lammps binary

    > with the input file.

  Returns:
    Workflow

## Module contents